Documentation
¶
Index ¶
- Variables
- func RegisterAuthServiceServer(s grpc.ServiceRegistrar, srv AuthServiceServer)
- func RegisterCourseServiceServer(s grpc.ServiceRegistrar, srv CourseServiceServer)
- func RegisterSchoolServiceServer(s grpc.ServiceRegistrar, srv SchoolServiceServer)
- type AuthServiceClient
- type AuthServiceServer
- type Class
- func (*Class) Descriptor() ([]byte, []int)deprecated
- func (x *Class) GetHeadTeacher() int64
- func (x *Class) GetId() int64
- func (x *Class) GetName() string
- func (x *Class) GetSchoolId() int64
- func (*Class) ProtoMessage()
- func (x *Class) ProtoReflect() protoreflect.Message
- func (x *Class) Reset()
- func (x *Class) String() string
- type ClassID
- type ClassRequest
- func (*ClassRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ClassRequest) GetHeadTeacher() int64
- func (x *ClassRequest) GetName() string
- func (x *ClassRequest) GetSchoolId() int64
- func (*ClassRequest) ProtoMessage()
- func (x *ClassRequest) ProtoReflect() protoreflect.Message
- func (x *ClassRequest) Reset()
- func (x *ClassRequest) String() string
- type ClassResponse
- func (*ClassResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ClassResponse) GetData() *Class
- func (x *ClassResponse) GetError() string
- func (x *ClassResponse) GetStatus() int64
- func (*ClassResponse) ProtoMessage()
- func (x *ClassResponse) ProtoReflect() protoreflect.Message
- func (x *ClassResponse) Reset()
- func (x *ClassResponse) String() string
- type Course
- func (*Course) Descriptor() ([]byte, []int)deprecated
- func (x *Course) GetClassId() int64
- func (x *Course) GetId() int64
- func (x *Course) GetMarks() []*Mark
- func (x *Course) GetName() string
- func (x *Course) GetTeacherId() int64
- func (*Course) ProtoMessage()
- func (x *Course) ProtoReflect() protoreflect.Message
- func (x *Course) Reset()
- func (x *Course) String() string
- type CourseCreateResponse
- func (*CourseCreateResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CourseCreateResponse) GetError() string
- func (x *CourseCreateResponse) GetStatus() int64
- func (*CourseCreateResponse) ProtoMessage()
- func (x *CourseCreateResponse) ProtoReflect() protoreflect.Message
- func (x *CourseCreateResponse) Reset()
- func (x *CourseCreateResponse) String() string
- type CourseID
- type CourseRequest
- func (*CourseRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CourseRequest) GetClassId() int64
- func (x *CourseRequest) GetName() string
- func (x *CourseRequest) GetTeacherId() int64
- func (*CourseRequest) ProtoMessage()
- func (x *CourseRequest) ProtoReflect() protoreflect.Message
- func (x *CourseRequest) Reset()
- func (x *CourseRequest) String() string
- type CourseResponse
- func (*CourseResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CourseResponse) GetData() *Course
- func (x *CourseResponse) GetError() string
- func (x *CourseResponse) GetStatus() int64
- func (*CourseResponse) ProtoMessage()
- func (x *CourseResponse) ProtoReflect() protoreflect.Message
- func (x *CourseResponse) Reset()
- func (x *CourseResponse) String() string
- type CourseServiceClient
- type CourseServiceServer
- type DeleteResponse
- func (*DeleteResponse) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteResponse) GetError() string
- func (x *DeleteResponse) GetStatus() int64
- func (*DeleteResponse) ProtoMessage()
- func (x *DeleteResponse) ProtoReflect() protoreflect.Message
- func (x *DeleteResponse) Reset()
- func (x *DeleteResponse) String() string
- type HealthRequest
- type HealthResponse
- type LessonRequest
- func (*LessonRequest) Descriptor() ([]byte, []int)deprecated
- func (x *LessonRequest) GetClassRoom() string
- func (x *LessonRequest) GetCourseId() int64
- func (x *LessonRequest) GetEndHour() string
- func (x *LessonRequest) GetName() string
- func (x *LessonRequest) GetStartHour() string
- func (x *LessonRequest) GetWeekDay() string
- func (*LessonRequest) ProtoMessage()
- func (x *LessonRequest) ProtoReflect() protoreflect.Message
- func (x *LessonRequest) Reset()
- func (x *LessonRequest) String() string
- type LoginRequest
- func (*LoginRequest) Descriptor() ([]byte, []int)deprecated
- func (x *LoginRequest) GetEmail() string
- func (x *LoginRequest) GetPassword() string
- func (*LoginRequest) ProtoMessage()
- func (x *LoginRequest) ProtoReflect() protoreflect.Message
- func (x *LoginRequest) Reset()
- func (x *LoginRequest) String() string
- type LoginResponse
- func (*LoginResponse) Descriptor() ([]byte, []int)deprecated
- func (x *LoginResponse) GetError() string
- func (x *LoginResponse) GetStatus() int64
- func (x *LoginResponse) GetToken() string
- func (*LoginResponse) ProtoMessage()
- func (x *LoginResponse) ProtoReflect() protoreflect.Message
- func (x *LoginResponse) Reset()
- func (x *LoginResponse) String() string
- type Mark
- func (*Mark) Descriptor() ([]byte, []int)deprecated
- func (x *Mark) GetCourseId() int64
- func (x *Mark) GetId() int64
- func (x *Mark) GetIsAbsent() bool
- func (x *Mark) GetMark() int32
- func (x *Mark) GetMarkDate() string
- func (x *Mark) GetStudentId() int64
- func (*Mark) ProtoMessage()
- func (x *Mark) ProtoReflect() protoreflect.Message
- func (x *Mark) Reset()
- func (x *Mark) String() string
- type MarkRequest
- func (*MarkRequest) Descriptor() ([]byte, []int)deprecated
- func (x *MarkRequest) GetCourseId() int64
- func (x *MarkRequest) GetIsAbsent() bool
- func (x *MarkRequest) GetMark() int32
- func (x *MarkRequest) GetMarkDate() string
- func (x *MarkRequest) GetStudentId() int64
- func (*MarkRequest) ProtoMessage()
- func (x *MarkRequest) ProtoReflect() protoreflect.Message
- func (x *MarkRequest) Reset()
- func (x *MarkRequest) String() string
- type RegisterRequest
- func (*RegisterRequest) Descriptor() ([]byte, []int)deprecated
- func (x *RegisterRequest) GetEmail() string
- func (x *RegisterRequest) GetName() string
- func (x *RegisterRequest) GetPassword() string
- func (x *RegisterRequest) GetRoleId() int64
- func (x *RegisterRequest) GetSchoolId() int64
- func (*RegisterRequest) ProtoMessage()
- func (x *RegisterRequest) ProtoReflect() protoreflect.Message
- func (x *RegisterRequest) Reset()
- func (x *RegisterRequest) String() string
- type RegisterResponse
- func (*RegisterResponse) Descriptor() ([]byte, []int)deprecated
- func (x *RegisterResponse) GetError() string
- func (x *RegisterResponse) GetStatus() int64
- func (x *RegisterResponse) GetUserId() int64
- func (*RegisterResponse) ProtoMessage()
- func (x *RegisterResponse) ProtoReflect() protoreflect.Message
- func (x *RegisterResponse) Reset()
- func (x *RegisterResponse) String() string
- type SchoolCreateResponse
- func (*SchoolCreateResponse) Descriptor() ([]byte, []int)deprecated
- func (x *SchoolCreateResponse) GetError() string
- func (x *SchoolCreateResponse) GetStatus() int64
- func (*SchoolCreateResponse) ProtoMessage()
- func (x *SchoolCreateResponse) ProtoReflect() protoreflect.Message
- func (x *SchoolCreateResponse) Reset()
- func (x *SchoolCreateResponse) String() string
- type SchoolRequest
- type SchoolServiceClient
- type SchoolServiceServer
- type StudentRequest
- func (*StudentRequest) Descriptor() ([]byte, []int)deprecated
- func (x *StudentRequest) GetClassID() int64
- func (x *StudentRequest) GetUserID() int64
- func (*StudentRequest) ProtoMessage()
- func (x *StudentRequest) ProtoReflect() protoreflect.Message
- func (x *StudentRequest) Reset()
- func (x *StudentRequest) String() string
- type UnimplementedAuthServiceServer
- func (UnimplementedAuthServiceServer) DeleteUser(context.Context, *UserID) (*DeleteResponse, error)
- func (UnimplementedAuthServiceServer) GetUser(context.Context, *UserID) (*UserResponse, error)
- func (UnimplementedAuthServiceServer) Login(context.Context, *LoginRequest) (*LoginResponse, error)
- func (UnimplementedAuthServiceServer) Register(context.Context, *RegisterRequest) (*RegisterResponse, error)
- func (UnimplementedAuthServiceServer) Validate(context.Context, *ValidateRequest) (*ValidateResponse, error)
- type UnimplementedCourseServiceServer
- func (UnimplementedCourseServiceServer) CheckHealth(context.Context, *HealthRequest) (*HealthResponse, error)
- func (UnimplementedCourseServiceServer) CreateCourse(context.Context, *CourseRequest) (*CourseCreateResponse, error)
- func (UnimplementedCourseServiceServer) CreateLesson(context.Context, *LessonRequest) (*CourseCreateResponse, error)
- func (UnimplementedCourseServiceServer) CreateMark(context.Context, *MarkRequest) (*CourseCreateResponse, error)
- func (UnimplementedCourseServiceServer) GetCourse(context.Context, *CourseID) (*CourseResponse, error)
- type UnimplementedSchoolServiceServer
- func (UnimplementedSchoolServiceServer) CreateClass(context.Context, *ClassRequest) (*SchoolCreateResponse, error)
- func (UnimplementedSchoolServiceServer) CreateSchool(context.Context, *SchoolRequest) (*SchoolCreateResponse, error)
- func (UnimplementedSchoolServiceServer) CreateStudent(context.Context, *StudentRequest) (*SchoolCreateResponse, error)
- func (UnimplementedSchoolServiceServer) GetClass(context.Context, *ClassID) (*ClassResponse, error)
- type UnsafeAuthServiceServer
- type UnsafeCourseServiceServer
- type UnsafeSchoolServiceServer
- type User
- func (*User) Descriptor() ([]byte, []int)deprecated
- func (x *User) GetEmail() string
- func (x *User) GetId() int64
- func (x *User) GetName() string
- func (x *User) GetRoleId() int64
- func (x *User) GetSchoolId() int64
- func (*User) ProtoMessage()
- func (x *User) ProtoReflect() protoreflect.Message
- func (x *User) Reset()
- func (x *User) String() string
- type UserID
- type UserResponse
- func (*UserResponse) Descriptor() ([]byte, []int)deprecated
- func (x *UserResponse) GetData() *User
- func (x *UserResponse) GetError() string
- func (x *UserResponse) GetStatus() int64
- func (*UserResponse) ProtoMessage()
- func (x *UserResponse) ProtoReflect() protoreflect.Message
- func (x *UserResponse) Reset()
- func (x *UserResponse) String() string
- type ValidateRequest
- type ValidateResponse
- func (*ValidateResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ValidateResponse) GetError() string
- func (x *ValidateResponse) GetStatus() int64
- func (x *ValidateResponse) GetUserId() int64
- func (*ValidateResponse) ProtoMessage()
- func (x *ValidateResponse) ProtoReflect() protoreflect.Message
- func (x *ValidateResponse) Reset()
- func (x *ValidateResponse) String() string
Constants ¶
This section is empty.
Variables ¶
var AuthService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "auth.AuthService", HandlerType: (*AuthServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetUser", Handler: _AuthService_GetUser_Handler, }, { MethodName: "Register", Handler: _AuthService_Register_Handler, }, { MethodName: "Login", Handler: _AuthService_Login_Handler, }, { MethodName: "Validate", Handler: _AuthService_Validate_Handler, }, { MethodName: "DeleteUser", Handler: _AuthService_DeleteUser_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "pkg/pb/auth.proto", }
AuthService_ServiceDesc is the grpc.ServiceDesc for AuthService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var CourseService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "course.CourseService", HandlerType: (*CourseServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateCourse", Handler: _CourseService_CreateCourse_Handler, }, { MethodName: "GetCourse", Handler: _CourseService_GetCourse_Handler, }, { MethodName: "CreateLesson", Handler: _CourseService_CreateLesson_Handler, }, { MethodName: "CreateMark", Handler: _CourseService_CreateMark_Handler, }, { MethodName: "CheckHealth", Handler: _CourseService_CheckHealth_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "pkg/pb/course.proto", }
CourseService_ServiceDesc is the grpc.ServiceDesc for CourseService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_pkg_pb_auth_proto protoreflect.FileDescriptor
var File_pkg_pb_course_proto protoreflect.FileDescriptor
var File_pkg_pb_school_proto protoreflect.FileDescriptor
var SchoolService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "school.SchoolService", HandlerType: (*SchoolServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateSchool", Handler: _SchoolService_CreateSchool_Handler, }, { MethodName: "CreateClass", Handler: _SchoolService_CreateClass_Handler, }, { MethodName: "GetClass", Handler: _SchoolService_GetClass_Handler, }, { MethodName: "CreateStudent", Handler: _SchoolService_CreateStudent_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "pkg/pb/school.proto", }
SchoolService_ServiceDesc is the grpc.ServiceDesc for SchoolService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterAuthServiceServer ¶
func RegisterAuthServiceServer(s grpc.ServiceRegistrar, srv AuthServiceServer)
func RegisterCourseServiceServer ¶
func RegisterCourseServiceServer(s grpc.ServiceRegistrar, srv CourseServiceServer)
func RegisterSchoolServiceServer ¶
func RegisterSchoolServiceServer(s grpc.ServiceRegistrar, srv SchoolServiceServer)
Types ¶
type AuthServiceClient ¶
type AuthServiceClient interface {
GetUser(ctx context.Context, in *UserID, opts ...grpc.CallOption) (*UserResponse, error)
Register(ctx context.Context, in *RegisterRequest, opts ...grpc.CallOption) (*RegisterResponse, error)
Login(ctx context.Context, in *LoginRequest, opts ...grpc.CallOption) (*LoginResponse, error)
Validate(ctx context.Context, in *ValidateRequest, opts ...grpc.CallOption) (*ValidateResponse, error)
DeleteUser(ctx context.Context, in *UserID, opts ...grpc.CallOption) (*DeleteResponse, error)
}
AuthServiceClient is the client API for AuthService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewAuthServiceClient ¶
func NewAuthServiceClient(cc grpc.ClientConnInterface) AuthServiceClient
type AuthServiceServer ¶
type AuthServiceServer interface {
GetUser(context.Context, *UserID) (*UserResponse, error)
Register(context.Context, *RegisterRequest) (*RegisterResponse, error)
Login(context.Context, *LoginRequest) (*LoginResponse, error)
Validate(context.Context, *ValidateRequest) (*ValidateResponse, error)
DeleteUser(context.Context, *UserID) (*DeleteResponse, error)
}
AuthServiceServer is the server API for AuthService service. All implementations should embed UnimplementedAuthServiceServer for forward compatibility
type Class ¶
type Class struct {
Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
HeadTeacher int64 `protobuf:"varint,3,opt,name=headTeacher,proto3" json:"headTeacher,omitempty"`
SchoolId int64 `protobuf:"varint,4,opt,name=schoolId,proto3" json:"schoolId,omitempty"`
// contains filtered or unexported fields
}
func (*Class) Descriptor
deprecated
func (*Class) GetHeadTeacher ¶
func (*Class) GetSchoolId ¶
func (*Class) ProtoMessage ¶
func (*Class) ProtoMessage()
func (*Class) ProtoReflect ¶
func (x *Class) ProtoReflect() protoreflect.Message
type ClassID ¶
type ClassID struct {
Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
func (*ClassID) Descriptor
deprecated
func (*ClassID) ProtoMessage ¶
func (*ClassID) ProtoMessage()
func (*ClassID) ProtoReflect ¶
func (x *ClassID) ProtoReflect() protoreflect.Message
type ClassRequest ¶
type ClassRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
HeadTeacher int64 `protobuf:"varint,2,opt,name=headTeacher,proto3" json:"headTeacher,omitempty"`
SchoolId int64 `protobuf:"varint,3,opt,name=schoolId,proto3" json:"schoolId,omitempty"`
// contains filtered or unexported fields
}
func (*ClassRequest) Descriptor
deprecated
func (*ClassRequest) Descriptor() ([]byte, []int)
Deprecated: Use ClassRequest.ProtoReflect.Descriptor instead.
func (*ClassRequest) GetHeadTeacher ¶
func (x *ClassRequest) GetHeadTeacher() int64
func (*ClassRequest) GetName ¶
func (x *ClassRequest) GetName() string
func (*ClassRequest) GetSchoolId ¶
func (x *ClassRequest) GetSchoolId() int64
func (*ClassRequest) ProtoMessage ¶
func (*ClassRequest) ProtoMessage()
func (*ClassRequest) ProtoReflect ¶
func (x *ClassRequest) ProtoReflect() protoreflect.Message
func (*ClassRequest) Reset ¶
func (x *ClassRequest) Reset()
func (*ClassRequest) String ¶
func (x *ClassRequest) String() string
type ClassResponse ¶
type ClassResponse struct {
Status int64 `protobuf:"varint,1,opt,name=status,proto3" json:"status,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
Data *Class `protobuf:"bytes,3,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
func (*ClassResponse) Descriptor
deprecated
func (*ClassResponse) Descriptor() ([]byte, []int)
Deprecated: Use ClassResponse.ProtoReflect.Descriptor instead.
func (*ClassResponse) GetData ¶
func (x *ClassResponse) GetData() *Class
func (*ClassResponse) GetError ¶
func (x *ClassResponse) GetError() string
func (*ClassResponse) GetStatus ¶
func (x *ClassResponse) GetStatus() int64
func (*ClassResponse) ProtoMessage ¶
func (*ClassResponse) ProtoMessage()
func (*ClassResponse) ProtoReflect ¶
func (x *ClassResponse) ProtoReflect() protoreflect.Message
func (*ClassResponse) Reset ¶
func (x *ClassResponse) Reset()
func (*ClassResponse) String ¶
func (x *ClassResponse) String() string
type Course ¶
type Course struct {
Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
TeacherId int64 `protobuf:"varint,3,opt,name=teacherId,proto3" json:"teacherId,omitempty"`
ClassId int64 `protobuf:"varint,4,opt,name=classId,proto3" json:"classId,omitempty"`
Marks []*Mark `protobuf:"bytes,5,rep,name=marks,proto3" json:"marks,omitempty"`
// contains filtered or unexported fields
}
func (*Course) Descriptor
deprecated
func (*Course) GetClassId ¶
func (*Course) GetTeacherId ¶
func (*Course) ProtoMessage ¶
func (*Course) ProtoMessage()
func (*Course) ProtoReflect ¶
func (x *Course) ProtoReflect() protoreflect.Message
type CourseCreateResponse ¶
type CourseCreateResponse struct {
Status int64 `protobuf:"varint,1,opt,name=status,proto3" json:"status,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*CourseCreateResponse) Descriptor
deprecated
func (*CourseCreateResponse) Descriptor() ([]byte, []int)
Deprecated: Use CourseCreateResponse.ProtoReflect.Descriptor instead.
func (*CourseCreateResponse) GetError ¶
func (x *CourseCreateResponse) GetError() string
func (*CourseCreateResponse) GetStatus ¶
func (x *CourseCreateResponse) GetStatus() int64
func (*CourseCreateResponse) ProtoMessage ¶
func (*CourseCreateResponse) ProtoMessage()
func (*CourseCreateResponse) ProtoReflect ¶
func (x *CourseCreateResponse) ProtoReflect() protoreflect.Message
func (*CourseCreateResponse) Reset ¶
func (x *CourseCreateResponse) Reset()
func (*CourseCreateResponse) String ¶
func (x *CourseCreateResponse) String() string
type CourseID ¶
type CourseID struct {
Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
func (*CourseID) Descriptor
deprecated
func (*CourseID) ProtoMessage ¶
func (*CourseID) ProtoMessage()
func (*CourseID) ProtoReflect ¶
func (x *CourseID) ProtoReflect() protoreflect.Message
type CourseRequest ¶
type CourseRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
TeacherId int64 `protobuf:"varint,2,opt,name=teacherId,proto3" json:"teacherId,omitempty"`
ClassId int64 `protobuf:"varint,3,opt,name=classId,proto3" json:"classId,omitempty"`
// contains filtered or unexported fields
}
func (*CourseRequest) Descriptor
deprecated
func (*CourseRequest) Descriptor() ([]byte, []int)
Deprecated: Use CourseRequest.ProtoReflect.Descriptor instead.
func (*CourseRequest) GetClassId ¶
func (x *CourseRequest) GetClassId() int64
func (*CourseRequest) GetName ¶
func (x *CourseRequest) GetName() string
func (*CourseRequest) GetTeacherId ¶
func (x *CourseRequest) GetTeacherId() int64
func (*CourseRequest) ProtoMessage ¶
func (*CourseRequest) ProtoMessage()
func (*CourseRequest) ProtoReflect ¶
func (x *CourseRequest) ProtoReflect() protoreflect.Message
func (*CourseRequest) Reset ¶
func (x *CourseRequest) Reset()
func (*CourseRequest) String ¶
func (x *CourseRequest) String() string
type CourseResponse ¶
type CourseResponse struct {
Status int64 `protobuf:"varint,1,opt,name=status,proto3" json:"status,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
Data *Course `protobuf:"bytes,3,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
func (*CourseResponse) Descriptor
deprecated
func (*CourseResponse) Descriptor() ([]byte, []int)
Deprecated: Use CourseResponse.ProtoReflect.Descriptor instead.
func (*CourseResponse) GetData ¶
func (x *CourseResponse) GetData() *Course
func (*CourseResponse) GetError ¶
func (x *CourseResponse) GetError() string
func (*CourseResponse) GetStatus ¶
func (x *CourseResponse) GetStatus() int64
func (*CourseResponse) ProtoMessage ¶
func (*CourseResponse) ProtoMessage()
func (*CourseResponse) ProtoReflect ¶
func (x *CourseResponse) ProtoReflect() protoreflect.Message
func (*CourseResponse) Reset ¶
func (x *CourseResponse) Reset()
func (*CourseResponse) String ¶
func (x *CourseResponse) String() string
type CourseServiceClient ¶
type CourseServiceClient interface {
CreateCourse(ctx context.Context, in *CourseRequest, opts ...grpc.CallOption) (*CourseCreateResponse, error)
GetCourse(ctx context.Context, in *CourseID, opts ...grpc.CallOption) (*CourseResponse, error)
CreateLesson(ctx context.Context, in *LessonRequest, opts ...grpc.CallOption) (*CourseCreateResponse, error)
CreateMark(ctx context.Context, in *MarkRequest, opts ...grpc.CallOption) (*CourseCreateResponse, error)
CheckHealth(ctx context.Context, in *HealthRequest, opts ...grpc.CallOption) (*HealthResponse, error)
}
CourseServiceClient is the client API for CourseService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewCourseServiceClient ¶
func NewCourseServiceClient(cc grpc.ClientConnInterface) CourseServiceClient
type CourseServiceServer ¶
type CourseServiceServer interface {
CreateCourse(context.Context, *CourseRequest) (*CourseCreateResponse, error)
GetCourse(context.Context, *CourseID) (*CourseResponse, error)
CreateLesson(context.Context, *LessonRequest) (*CourseCreateResponse, error)
CreateMark(context.Context, *MarkRequest) (*CourseCreateResponse, error)
CheckHealth(context.Context, *HealthRequest) (*HealthResponse, error)
}
CourseServiceServer is the server API for CourseService service. All implementations should embed UnimplementedCourseServiceServer for forward compatibility
type DeleteResponse ¶
type DeleteResponse struct {
Status int64 `protobuf:"varint,1,opt,name=status,proto3" json:"status,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteResponse) Descriptor
deprecated
func (*DeleteResponse) Descriptor() ([]byte, []int)
Deprecated: Use DeleteResponse.ProtoReflect.Descriptor instead.
func (*DeleteResponse) GetError ¶
func (x *DeleteResponse) GetError() string
func (*DeleteResponse) GetStatus ¶
func (x *DeleteResponse) GetStatus() int64
func (*DeleteResponse) ProtoMessage ¶
func (*DeleteResponse) ProtoMessage()
func (*DeleteResponse) ProtoReflect ¶
func (x *DeleteResponse) ProtoReflect() protoreflect.Message
func (*DeleteResponse) Reset ¶
func (x *DeleteResponse) Reset()
func (*DeleteResponse) String ¶
func (x *DeleteResponse) String() string
type HealthRequest ¶
type HealthRequest struct {
Check bool `protobuf:"varint,1,opt,name=check,proto3" json:"check,omitempty"`
// contains filtered or unexported fields
}
func (*HealthRequest) Descriptor
deprecated
func (*HealthRequest) Descriptor() ([]byte, []int)
Deprecated: Use HealthRequest.ProtoReflect.Descriptor instead.
func (*HealthRequest) GetCheck ¶
func (x *HealthRequest) GetCheck() bool
func (*HealthRequest) ProtoMessage ¶
func (*HealthRequest) ProtoMessage()
func (*HealthRequest) ProtoReflect ¶
func (x *HealthRequest) ProtoReflect() protoreflect.Message
func (*HealthRequest) Reset ¶
func (x *HealthRequest) Reset()
func (*HealthRequest) String ¶
func (x *HealthRequest) String() string
type HealthResponse ¶
type HealthResponse struct {
Healthy bool `protobuf:"varint,1,opt,name=healthy,proto3" json:"healthy,omitempty"`
// contains filtered or unexported fields
}
func (*HealthResponse) Descriptor
deprecated
func (*HealthResponse) Descriptor() ([]byte, []int)
Deprecated: Use HealthResponse.ProtoReflect.Descriptor instead.
func (*HealthResponse) GetHealthy ¶
func (x *HealthResponse) GetHealthy() bool
func (*HealthResponse) ProtoMessage ¶
func (*HealthResponse) ProtoMessage()
func (*HealthResponse) ProtoReflect ¶
func (x *HealthResponse) ProtoReflect() protoreflect.Message
func (*HealthResponse) Reset ¶
func (x *HealthResponse) Reset()
func (*HealthResponse) String ¶
func (x *HealthResponse) String() string
type LessonRequest ¶
type LessonRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
CourseId int64 `protobuf:"varint,2,opt,name=courseId,proto3" json:"courseId,omitempty"`
StartHour string `protobuf:"bytes,3,opt,name=startHour,proto3" json:"startHour,omitempty"`
EndHour string `protobuf:"bytes,4,opt,name=endHour,proto3" json:"endHour,omitempty"`
WeekDay string `protobuf:"bytes,5,opt,name=weekDay,proto3" json:"weekDay,omitempty"`
ClassRoom string `protobuf:"bytes,6,opt,name=classRoom,proto3" json:"classRoom,omitempty"`
// contains filtered or unexported fields
}
func (*LessonRequest) Descriptor
deprecated
func (*LessonRequest) Descriptor() ([]byte, []int)
Deprecated: Use LessonRequest.ProtoReflect.Descriptor instead.
func (*LessonRequest) GetClassRoom ¶
func (x *LessonRequest) GetClassRoom() string
func (*LessonRequest) GetCourseId ¶
func (x *LessonRequest) GetCourseId() int64
func (*LessonRequest) GetEndHour ¶
func (x *LessonRequest) GetEndHour() string
func (*LessonRequest) GetName ¶
func (x *LessonRequest) GetName() string
func (*LessonRequest) GetStartHour ¶
func (x *LessonRequest) GetStartHour() string
func (*LessonRequest) GetWeekDay ¶
func (x *LessonRequest) GetWeekDay() string
func (*LessonRequest) ProtoMessage ¶
func (*LessonRequest) ProtoMessage()
func (*LessonRequest) ProtoReflect ¶
func (x *LessonRequest) ProtoReflect() protoreflect.Message
func (*LessonRequest) Reset ¶
func (x *LessonRequest) Reset()
func (*LessonRequest) String ¶
func (x *LessonRequest) String() string
type LoginRequest ¶
type LoginRequest struct {
Email string `protobuf:"bytes,1,opt,name=email,proto3" json:"email,omitempty"`
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
// contains filtered or unexported fields
}
func (*LoginRequest) Descriptor
deprecated
func (*LoginRequest) Descriptor() ([]byte, []int)
Deprecated: Use LoginRequest.ProtoReflect.Descriptor instead.
func (*LoginRequest) GetEmail ¶
func (x *LoginRequest) GetEmail() string
func (*LoginRequest) GetPassword ¶
func (x *LoginRequest) GetPassword() string
func (*LoginRequest) ProtoMessage ¶
func (*LoginRequest) ProtoMessage()
func (*LoginRequest) ProtoReflect ¶
func (x *LoginRequest) ProtoReflect() protoreflect.Message
func (*LoginRequest) Reset ¶
func (x *LoginRequest) Reset()
func (*LoginRequest) String ¶
func (x *LoginRequest) String() string
type LoginResponse ¶
type LoginResponse struct {
Status int64 `protobuf:"varint,1,opt,name=status,proto3" json:"status,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
Token string `protobuf:"bytes,3,opt,name=token,proto3" json:"token,omitempty"`
// contains filtered or unexported fields
}
func (*LoginResponse) Descriptor
deprecated
func (*LoginResponse) Descriptor() ([]byte, []int)
Deprecated: Use LoginResponse.ProtoReflect.Descriptor instead.
func (*LoginResponse) GetError ¶
func (x *LoginResponse) GetError() string
func (*LoginResponse) GetStatus ¶
func (x *LoginResponse) GetStatus() int64
func (*LoginResponse) GetToken ¶
func (x *LoginResponse) GetToken() string
func (*LoginResponse) ProtoMessage ¶
func (*LoginResponse) ProtoMessage()
func (*LoginResponse) ProtoReflect ¶
func (x *LoginResponse) ProtoReflect() protoreflect.Message
func (*LoginResponse) Reset ¶
func (x *LoginResponse) Reset()
func (*LoginResponse) String ¶
func (x *LoginResponse) String() string
type Mark ¶
type Mark struct {
Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
CourseId int64 `protobuf:"varint,2,opt,name=courseId,proto3" json:"courseId,omitempty"`
MarkDate string `protobuf:"bytes,3,opt,name=markDate,proto3" json:"markDate,omitempty"`
IsAbsent bool `protobuf:"varint,4,opt,name=isAbsent,proto3" json:"isAbsent,omitempty"`
Mark int32 `protobuf:"varint,5,opt,name=mark,proto3" json:"mark,omitempty"`
StudentId int64 `protobuf:"varint,6,opt,name=studentId,proto3" json:"studentId,omitempty"`
// contains filtered or unexported fields
}
func (*Mark) Descriptor
deprecated
func (*Mark) GetCourseId ¶
func (*Mark) GetIsAbsent ¶
func (*Mark) GetMarkDate ¶
func (*Mark) GetStudentId ¶
func (*Mark) ProtoMessage ¶
func (*Mark) ProtoMessage()
func (*Mark) ProtoReflect ¶
func (x *Mark) ProtoReflect() protoreflect.Message
type MarkRequest ¶
type MarkRequest struct {
CourseId int64 `protobuf:"varint,1,opt,name=courseId,proto3" json:"courseId,omitempty"`
MarkDate string `protobuf:"bytes,2,opt,name=markDate,proto3" json:"markDate,omitempty"`
IsAbsent bool `protobuf:"varint,3,opt,name=isAbsent,proto3" json:"isAbsent,omitempty"`
Mark int32 `protobuf:"varint,4,opt,name=mark,proto3" json:"mark,omitempty"`
StudentId int64 `protobuf:"varint,5,opt,name=studentId,proto3" json:"studentId,omitempty"`
// contains filtered or unexported fields
}
func (*MarkRequest) Descriptor
deprecated
func (*MarkRequest) Descriptor() ([]byte, []int)
Deprecated: Use MarkRequest.ProtoReflect.Descriptor instead.
func (*MarkRequest) GetCourseId ¶
func (x *MarkRequest) GetCourseId() int64
func (*MarkRequest) GetIsAbsent ¶
func (x *MarkRequest) GetIsAbsent() bool
func (*MarkRequest) GetMark ¶
func (x *MarkRequest) GetMark() int32
func (*MarkRequest) GetMarkDate ¶
func (x *MarkRequest) GetMarkDate() string
func (*MarkRequest) GetStudentId ¶
func (x *MarkRequest) GetStudentId() int64
func (*MarkRequest) ProtoMessage ¶
func (*MarkRequest) ProtoMessage()
func (*MarkRequest) ProtoReflect ¶
func (x *MarkRequest) ProtoReflect() protoreflect.Message
func (*MarkRequest) Reset ¶
func (x *MarkRequest) Reset()
func (*MarkRequest) String ¶
func (x *MarkRequest) String() string
type RegisterRequest ¶
type RegisterRequest struct {
Email string `protobuf:"bytes,1,opt,name=email,proto3" json:"email,omitempty"`
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
Name string `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
SchoolId int64 `protobuf:"varint,4,opt,name=schoolId,proto3" json:"schoolId,omitempty"`
RoleId int64 `protobuf:"varint,5,opt,name=roleId,proto3" json:"roleId,omitempty"`
// contains filtered or unexported fields
}
func (*RegisterRequest) Descriptor
deprecated
func (*RegisterRequest) Descriptor() ([]byte, []int)
Deprecated: Use RegisterRequest.ProtoReflect.Descriptor instead.
func (*RegisterRequest) GetEmail ¶
func (x *RegisterRequest) GetEmail() string
func (*RegisterRequest) GetName ¶
func (x *RegisterRequest) GetName() string
func (*RegisterRequest) GetPassword ¶
func (x *RegisterRequest) GetPassword() string
func (*RegisterRequest) GetRoleId ¶
func (x *RegisterRequest) GetRoleId() int64
func (*RegisterRequest) GetSchoolId ¶
func (x *RegisterRequest) GetSchoolId() int64
func (*RegisterRequest) ProtoMessage ¶
func (*RegisterRequest) ProtoMessage()
func (*RegisterRequest) ProtoReflect ¶
func (x *RegisterRequest) ProtoReflect() protoreflect.Message
func (*RegisterRequest) Reset ¶
func (x *RegisterRequest) Reset()
func (*RegisterRequest) String ¶
func (x *RegisterRequest) String() string
type RegisterResponse ¶
type RegisterResponse struct {
Status int64 `protobuf:"varint,1,opt,name=status,proto3" json:"status,omitempty"`
UserId int64 `protobuf:"varint,2,opt,name=userId,proto3" json:"userId,omitempty"`
Error string `protobuf:"bytes,3,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*RegisterResponse) Descriptor
deprecated
func (*RegisterResponse) Descriptor() ([]byte, []int)
Deprecated: Use RegisterResponse.ProtoReflect.Descriptor instead.
func (*RegisterResponse) GetError ¶
func (x *RegisterResponse) GetError() string
func (*RegisterResponse) GetStatus ¶
func (x *RegisterResponse) GetStatus() int64
func (*RegisterResponse) GetUserId ¶
func (x *RegisterResponse) GetUserId() int64
func (*RegisterResponse) ProtoMessage ¶
func (*RegisterResponse) ProtoMessage()
func (*RegisterResponse) ProtoReflect ¶
func (x *RegisterResponse) ProtoReflect() protoreflect.Message
func (*RegisterResponse) Reset ¶
func (x *RegisterResponse) Reset()
func (*RegisterResponse) String ¶
func (x *RegisterResponse) String() string
type SchoolCreateResponse ¶
type SchoolCreateResponse struct {
Status int64 `protobuf:"varint,1,opt,name=status,proto3" json:"status,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*SchoolCreateResponse) Descriptor
deprecated
func (*SchoolCreateResponse) Descriptor() ([]byte, []int)
Deprecated: Use SchoolCreateResponse.ProtoReflect.Descriptor instead.
func (*SchoolCreateResponse) GetError ¶
func (x *SchoolCreateResponse) GetError() string
func (*SchoolCreateResponse) GetStatus ¶
func (x *SchoolCreateResponse) GetStatus() int64
func (*SchoolCreateResponse) ProtoMessage ¶
func (*SchoolCreateResponse) ProtoMessage()
func (*SchoolCreateResponse) ProtoReflect ¶
func (x *SchoolCreateResponse) ProtoReflect() protoreflect.Message
func (*SchoolCreateResponse) Reset ¶
func (x *SchoolCreateResponse) Reset()
func (*SchoolCreateResponse) String ¶
func (x *SchoolCreateResponse) String() string
type SchoolRequest ¶
type SchoolRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*SchoolRequest) Descriptor
deprecated
func (*SchoolRequest) Descriptor() ([]byte, []int)
Deprecated: Use SchoolRequest.ProtoReflect.Descriptor instead.
func (*SchoolRequest) GetName ¶
func (x *SchoolRequest) GetName() string
func (*SchoolRequest) ProtoMessage ¶
func (*SchoolRequest) ProtoMessage()
func (*SchoolRequest) ProtoReflect ¶
func (x *SchoolRequest) ProtoReflect() protoreflect.Message
func (*SchoolRequest) Reset ¶
func (x *SchoolRequest) Reset()
func (*SchoolRequest) String ¶
func (x *SchoolRequest) String() string
type SchoolServiceClient ¶
type SchoolServiceClient interface {
CreateSchool(ctx context.Context, in *SchoolRequest, opts ...grpc.CallOption) (*SchoolCreateResponse, error)
CreateClass(ctx context.Context, in *ClassRequest, opts ...grpc.CallOption) (*SchoolCreateResponse, error)
GetClass(ctx context.Context, in *ClassID, opts ...grpc.CallOption) (*ClassResponse, error)
CreateStudent(ctx context.Context, in *StudentRequest, opts ...grpc.CallOption) (*SchoolCreateResponse, error)
}
SchoolServiceClient is the client API for SchoolService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewSchoolServiceClient ¶
func NewSchoolServiceClient(cc grpc.ClientConnInterface) SchoolServiceClient
type SchoolServiceServer ¶
type SchoolServiceServer interface {
CreateSchool(context.Context, *SchoolRequest) (*SchoolCreateResponse, error)
CreateClass(context.Context, *ClassRequest) (*SchoolCreateResponse, error)
GetClass(context.Context, *ClassID) (*ClassResponse, error)
CreateStudent(context.Context, *StudentRequest) (*SchoolCreateResponse, error)
}
SchoolServiceServer is the server API for SchoolService service. All implementations should embed UnimplementedSchoolServiceServer for forward compatibility
type StudentRequest ¶
type StudentRequest struct {
UserID int64 `protobuf:"varint,1,opt,name=userID,proto3" json:"userID,omitempty"`
ClassID int64 `protobuf:"varint,2,opt,name=classID,proto3" json:"classID,omitempty"`
// contains filtered or unexported fields
}
func (*StudentRequest) Descriptor
deprecated
func (*StudentRequest) Descriptor() ([]byte, []int)
Deprecated: Use StudentRequest.ProtoReflect.Descriptor instead.
func (*StudentRequest) GetClassID ¶
func (x *StudentRequest) GetClassID() int64
func (*StudentRequest) GetUserID ¶
func (x *StudentRequest) GetUserID() int64
func (*StudentRequest) ProtoMessage ¶
func (*StudentRequest) ProtoMessage()
func (*StudentRequest) ProtoReflect ¶
func (x *StudentRequest) ProtoReflect() protoreflect.Message
func (*StudentRequest) Reset ¶
func (x *StudentRequest) Reset()
func (*StudentRequest) String ¶
func (x *StudentRequest) String() string
type UnimplementedAuthServiceServer ¶
type UnimplementedAuthServiceServer struct {
}
UnimplementedAuthServiceServer should be embedded to have forward compatible implementations.
func (UnimplementedAuthServiceServer) DeleteUser ¶
func (UnimplementedAuthServiceServer) DeleteUser(context.Context, *UserID) (*DeleteResponse, error)
func (UnimplementedAuthServiceServer) GetUser ¶
func (UnimplementedAuthServiceServer) GetUser(context.Context, *UserID) (*UserResponse, error)
func (UnimplementedAuthServiceServer) Login ¶
func (UnimplementedAuthServiceServer) Login(context.Context, *LoginRequest) (*LoginResponse, error)
func (UnimplementedAuthServiceServer) Register ¶
func (UnimplementedAuthServiceServer) Register(context.Context, *RegisterRequest) (*RegisterResponse, error)
func (UnimplementedAuthServiceServer) Validate ¶
func (UnimplementedAuthServiceServer) Validate(context.Context, *ValidateRequest) (*ValidateResponse, error)
type UnimplementedCourseServiceServer ¶
type UnimplementedCourseServiceServer struct {
}
UnimplementedCourseServiceServer should be embedded to have forward compatible implementations.
func (UnimplementedCourseServiceServer) CheckHealth ¶
func (UnimplementedCourseServiceServer) CheckHealth(context.Context, *HealthRequest) (*HealthResponse, error)
func (UnimplementedCourseServiceServer) CreateCourse ¶
func (UnimplementedCourseServiceServer) CreateCourse(context.Context, *CourseRequest) (*CourseCreateResponse, error)
func (UnimplementedCourseServiceServer) CreateLesson ¶
func (UnimplementedCourseServiceServer) CreateLesson(context.Context, *LessonRequest) (*CourseCreateResponse, error)
func (UnimplementedCourseServiceServer) CreateMark ¶
func (UnimplementedCourseServiceServer) CreateMark(context.Context, *MarkRequest) (*CourseCreateResponse, error)
func (UnimplementedCourseServiceServer) GetCourse ¶
func (UnimplementedCourseServiceServer) GetCourse(context.Context, *CourseID) (*CourseResponse, error)
type UnimplementedSchoolServiceServer ¶
type UnimplementedSchoolServiceServer struct {
}
UnimplementedSchoolServiceServer should be embedded to have forward compatible implementations.
func (UnimplementedSchoolServiceServer) CreateClass ¶
func (UnimplementedSchoolServiceServer) CreateClass(context.Context, *ClassRequest) (*SchoolCreateResponse, error)
func (UnimplementedSchoolServiceServer) CreateSchool ¶
func (UnimplementedSchoolServiceServer) CreateSchool(context.Context, *SchoolRequest) (*SchoolCreateResponse, error)
func (UnimplementedSchoolServiceServer) CreateStudent ¶
func (UnimplementedSchoolServiceServer) CreateStudent(context.Context, *StudentRequest) (*SchoolCreateResponse, error)
func (UnimplementedSchoolServiceServer) GetClass ¶
func (UnimplementedSchoolServiceServer) GetClass(context.Context, *ClassID) (*ClassResponse, error)
type UnsafeAuthServiceServer ¶
type UnsafeAuthServiceServer interface {
// contains filtered or unexported methods
}
UnsafeAuthServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuthServiceServer will result in compilation errors.
type UnsafeCourseServiceServer ¶
type UnsafeCourseServiceServer interface {
// contains filtered or unexported methods
}
UnsafeCourseServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CourseServiceServer will result in compilation errors.
type UnsafeSchoolServiceServer ¶
type UnsafeSchoolServiceServer interface {
// contains filtered or unexported methods
}
UnsafeSchoolServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SchoolServiceServer will result in compilation errors.
type User ¶
type User struct {
Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Email string `protobuf:"bytes,2,opt,name=email,proto3" json:"email,omitempty"`
Name string `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
SchoolId int64 `protobuf:"varint,4,opt,name=schoolId,proto3" json:"schoolId,omitempty"`
RoleId int64 `protobuf:"varint,5,opt,name=roleId,proto3" json:"roleId,omitempty"`
// contains filtered or unexported fields
}
func (*User) Descriptor
deprecated
func (*User) GetSchoolId ¶
func (*User) ProtoMessage ¶
func (*User) ProtoMessage()
func (*User) ProtoReflect ¶
func (x *User) ProtoReflect() protoreflect.Message
type UserID ¶
type UserID struct {
Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
func (*UserID) Descriptor
deprecated
func (*UserID) ProtoMessage ¶
func (*UserID) ProtoMessage()
func (*UserID) ProtoReflect ¶
func (x *UserID) ProtoReflect() protoreflect.Message
type UserResponse ¶
type UserResponse struct {
Status int64 `protobuf:"varint,1,opt,name=status,proto3" json:"status,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
Data *User `protobuf:"bytes,3,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
func (*UserResponse) Descriptor
deprecated
func (*UserResponse) Descriptor() ([]byte, []int)
Deprecated: Use UserResponse.ProtoReflect.Descriptor instead.
func (*UserResponse) GetData ¶
func (x *UserResponse) GetData() *User
func (*UserResponse) GetError ¶
func (x *UserResponse) GetError() string
func (*UserResponse) GetStatus ¶
func (x *UserResponse) GetStatus() int64
func (*UserResponse) ProtoMessage ¶
func (*UserResponse) ProtoMessage()
func (*UserResponse) ProtoReflect ¶
func (x *UserResponse) ProtoReflect() protoreflect.Message
func (*UserResponse) Reset ¶
func (x *UserResponse) Reset()
func (*UserResponse) String ¶
func (x *UserResponse) String() string
type ValidateRequest ¶
type ValidateRequest struct {
Token string `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
// contains filtered or unexported fields
}
func (*ValidateRequest) Descriptor
deprecated
func (*ValidateRequest) Descriptor() ([]byte, []int)
Deprecated: Use ValidateRequest.ProtoReflect.Descriptor instead.
func (*ValidateRequest) GetToken ¶
func (x *ValidateRequest) GetToken() string
func (*ValidateRequest) ProtoMessage ¶
func (*ValidateRequest) ProtoMessage()
func (*ValidateRequest) ProtoReflect ¶
func (x *ValidateRequest) ProtoReflect() protoreflect.Message
func (*ValidateRequest) Reset ¶
func (x *ValidateRequest) Reset()
func (*ValidateRequest) String ¶
func (x *ValidateRequest) String() string
type ValidateResponse ¶
type ValidateResponse struct {
Status int64 `protobuf:"varint,1,opt,name=status,proto3" json:"status,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
UserId int64 `protobuf:"varint,3,opt,name=userId,proto3" json:"userId,omitempty"`
// contains filtered or unexported fields
}
func (*ValidateResponse) Descriptor
deprecated
func (*ValidateResponse) Descriptor() ([]byte, []int)
Deprecated: Use ValidateResponse.ProtoReflect.Descriptor instead.
func (*ValidateResponse) GetError ¶
func (x *ValidateResponse) GetError() string
func (*ValidateResponse) GetStatus ¶
func (x *ValidateResponse) GetStatus() int64
func (*ValidateResponse) GetUserId ¶
func (x *ValidateResponse) GetUserId() int64
func (*ValidateResponse) ProtoMessage ¶
func (*ValidateResponse) ProtoMessage()
func (*ValidateResponse) ProtoReflect ¶
func (x *ValidateResponse) ProtoReflect() protoreflect.Message
func (*ValidateResponse) Reset ¶
func (x *ValidateResponse) Reset()
func (*ValidateResponse) String ¶
func (x *ValidateResponse) String() string